@@ -1,3 +1,7 @@
+"""Export public API."""
+
+from .version import __version__
+
 from pytorch_gan_metrics.utils import (
     ImageDataset,
     get_inception_score,
@@ -14,7 +18,6 @@ __all__ = [
     get_fid,
     get_fid_from_directory,
     get_inception_score_and_fid,
-    get_inception_score_and_fid_from_directory
+    get_inception_score_and_fid_from_directory,
+    __version__,
 ]
-
-__version__ = '0.3.0'
